@@ -5,12 +5,12 @@ from uuid import uuid4
 import bottle
 from bottle import HTTPResponse
 
-from pretenders import settings
-from pretenders.constants import FOREVER
-from pretenders.log import get_logger
-from pretenders.mock_servers.http.handler import HttpHandler
-from pretenders.mock_servers.smtp.handler import SmtpHandler
-from pretenders.server import app
+
+from pretenders.common.constants import FOREVER
+from pretenders.server.log import get_logger
+from pretenders.server.mock_servers.http.handler import HttpHandler
+from pretenders.server.mock_servers.smtp.handler import SmtpHandler
+from pretenders.server import app, settings
 from pretenders.server.apps import history
 
 
@@ -43,8 +43,9 @@ def exists_or_404(protocol, uid):
     try:
         get_pretenders(protocol)[uid]
     except KeyError:
-        raise HTTPResponse("No matching {0} mock: {1}".format(protocol, uid),
-                            status=404)
+        raise HTTPResponse(
+            "No matching {0} mock: {1}".format(protocol, uid),
+            status=404)
 
 
 @app.get('/<protocol:re:(http|smtp)>')
@@ -119,8 +120,6 @@ def pretender_delete(protocol):
         for uid, server in get_pretenders(protocol).copy().items():
 
             LOGGER.debug("Pretender: {0}".format(server))
-            if server.timeout == FOREVER:
-                continue
-            if server.last_call + server.timeout < now:
+            if server.is_expired:
                 LOGGER.info("Deleting pretender with UID: {0}".format(uid))
                 delete_mock(protocol, uid)
