@@ -1,9 +1,8 @@
 import bottle
 
-from pretenders import settings
-from pretenders.log import get_logger
+from pretenders.server.log import get_logger
 from pretenders.server.base import in_parent_process, save_pid_file
-from pretenders.server import data, pretender_app
+from pretenders.server import data, pretender_app, settings
 from pretenders.server.maintain import launch_maintainer
 
 LOGGER = get_logger('pretenders.server.server')
@@ -24,16 +23,20 @@ def run(host='localhost', port=8000):
 if __name__ == '__main__':
     import argparse
     parser = argparse.ArgumentParser(description='Start the server')
-    parser.add_argument('-H', '--host', dest='host', default='localhost',
-                help='host/IP to run the server on (default: localhost)')
-    parser.add_argument('-p', '--port', dest='port', type=int, default=8000,
-                help='port number to run the server on (default: 8000)')
-    parser.add_argument('-d', '--debug', dest="debug", default=False,
-                action="store_true",
-                help='set debug mode')
-    parser.add_argument('-t', '--timeout', dest='timeout', type=int,
-                default=120,
-                help='timeout before deleting stale pretenders')
+    parser.add_argument(
+        '-H', '--host', dest='host', default='localhost',
+        help='host/IP to run the server on (default: localhost)')
+    parser.add_argument(
+        '-p', '--port', dest='port', type=int, default=8000,
+        help='port number to run the server on (default: 8000)')
+    parser.add_argument(
+        '-d', '--debug', dest="debug", default=False,
+        action="store_true",
+        help='set debug mode')
+    parser.add_argument(
+        '-t', '--timeout', dest='timeout', type=int,
+        default=120,
+        help='timeout before deleting stale pretenders')
 
     args = parser.parse_args()
     bottle.debug(args.debug)
